<!DOCTYPE html>
<html>
<head>
    <title>List Files in Directory</title>
    <style>
		
		<style>
			/* Apply system font stack to all elements except h tags */
			body *:not(h1, h2, h3, h4, h5, h6, span) {
			    font-family: 'Roboto Mono', monospace, courier, BlinkMacSystemFont, 'Segoe UI', Roboto, Oxygen-Sans, Ubuntu, Cantarell, 'Helvetica Neue', sans-serif;
			    font-size: 13px;
			}
			table, td, th {
			    font-family: 'Roboto Mono', monospace, courier, BlinkMacSystemFont, 'Segoe UI', Roboto, Oxygen-Sans, Ubuntu, Cantarell, 'Helvetica Neue', sans-serif;
			    font-size: 14px;
			}
			

			/* Apply Helvetica font to h tags */
			h1, h2, h3, h4, h5, h6, span {
			    font-family: 'Helvetica Neue', Helvetica, sans-serif;
			    color: black;
			    font-weight: 300;
			}
			h1 {
			    padding: 8px 6px 0 6px;
			}
			
			
        table {
            border-collapse: collapse;
            width: 100%;
        }

        th, td {
            padding: 8px;
            text-align: left;
            border-bottom: 1px solid #ddd;
        }

        th.sortable {
            cursor: pointer;
        }

        th.sortable::after {
            content: '\25b2';
            margin-left: 5px;
        }

        th.sortable.desc::after {
            content: '\25bc';
            margin-left: 5px;
        }
    </style>
</head>
<body>
	<h1>File sizes found within the Data folder</h1>
    <table id="fileTable">
        <thead>
            <tr>
                <th class="sortable" data-sort="name">File Name</th>
                <th class="sortable" data-sort="size">File Size</th>
            </tr>
        </thead>
        <tbody id="fileList"></tbody>
    </table>

    <script>
        // Set the data directory path
        var dataDir = '../../data';

        // Fetch the list of files from the server
        fetch('webyep-lf.php?dir=' + encodeURIComponent(dataDir))
            .then(response => response.json())
            .then(data => {
                var table = document.getElementById('fileTable');
                var fileList = document.getElementById('fileList');
                var headers = table.getElementsByTagName('th');

                // Initialize sort order variables
                var sortColumn = '';
                var sortDirection = '';

                // Display the list of files in the HTML table
                function displayFiles() {
                    // Clear the table body
                    fileList.innerHTML = '';

                    data.forEach(file => {
                        var row = document.createElement('tr');
                        var fileNameCell = document.createElement('td');
                        var fileSizeCell = document.createElement('td');

                        fileNameCell.textContent = file.name;
                        fileSizeCell.textContent = formatSizeUnits(file.size);
                        fileSizeCell.setAttribute('data-size', file.size);

                        row.appendChild(fileNameCell);
                        row.appendChild(fileSizeCell);
                        fileList.appendChild(row);
                    });
                }

                // Function to sort the file list based on the selected column
                function sortFiles(column) {
                    if (sortColumn === column) {
                        // Toggle the sort direction if the same column is clicked
                        sortDirection = sortDirection === 'asc' ? 'desc' : 'asc';
                    } else {
                        // Set the sort column and default sort direction
                        sortColumn = column;
                        sortDirection = 'asc';
                    }

                    // Remove the sort indicator from other columns
                    Array.from(headers).forEach(header => {
                        header.classList.remove('desc');
                    });

                    // Add the sort indicator to the current column
                    var currentHeader = table.querySelector('th[data-sort="' + sortColumn + '"]');
                    currentHeader.classList.add(sortDirection);

                    // Perform the sorting
                    if (sortColumn === 'name') {
                        data.sort((a, b) => {
                            var valueA = a.name.toLowerCase();
                            var valueB = b.name.toLowerCase();

                            if (sortDirection === 'desc') {
                                return valueB.localeCompare(valueA);
                            } else {
                                return valueA.localeCompare(valueB);
                            }
                        });
                    } else if (sortColumn === 'size') {
                        data.sort((a, b) => {
                            var valueA = parseInt(a.size);
                            var valueB = parseInt(b.size);

                            if (sortDirection === 'desc') {
                                return valueB - valueA;
                            } else {
                                return valueA - valueB;
                            }
                        });
                    }

                    // Re-display the sorted files
                    displayFiles();
                }

                // Add click event listeners to the sortable headers
                Array.from(headers).forEach(header => {
                    header.addEventListener('click', function () {
                        var column = this.getAttribute('data-sort');
                        sortFiles(column);
                    });
                });

                // Initial display of files
                displayFiles();
            })
            .catch(error => console.error(error));

        // Function to format file sizes in bytes to human-readable format
        function formatSizeUnits(bytes) {
            if (bytes >= 1073741824) {
                return (bytes / 1073741824).toFixed(2) + ' GB';
            } else if (bytes >= 1048576) {
                return (bytes / 1048576).toFixed(2) + ' MB';
            } else if (bytes >= 1024) {
                return (bytes / 1024).toFixed(2) + ' KB';
            } else if (bytes > 1) {
                return bytes + ' bytes';
            } else if (bytes == 1) {
                return bytes + ' byte';
            } else {
                return '0 bytes';
            }
        }
    </script>
</body>
</html>
                         