<!DOCTYPE html>
<html>
<head>
    <title>Web Page Crawler</title>
</head>
<body>
    <h1>Web Page Crawler 3</h1>
<?php
function crawlWebsite($url, $level = 0)
{
    // Initialize an array to store the webpages
    $webpages = array();

    // Create a DOM document
    $dom = new DOMDocument();

    // Load the webpage
    @$dom->loadHTMLFile($url);

    // Get all anchor tags
    $links = $dom->getElementsByTagName('a');

    // Iterate over the anchor tags
    foreach ($links as $link) {
        $href = $link->getAttribute('href');

        // Check if the URL is absolute or root-relative
        if (filter_var($href, FILTER_VALIDATE_URL)) {
            // Absolute URL
            $webpages[] = $href;
        } else {
            // Root-relative URL, convert it to an absolute URL
            $absoluteUrl = resolveRootRelativeUrl($url, $href);
            $webpages[] = $absoluteUrl;
        }
    }

    // Crawl parent pages up to three levels
    if ($level < 3) {
        $parentUrl = resolveRootRelativeUrl($url, '../');
        if ($parentUrl !== $url) { // Avoid crawling the same URL again
            $parentPages = crawlWebsite($parentUrl, $level + 1);
            $webpages = array_merge($webpages, $parentPages);
        }
    }

    return $webpages;
}

// Function to resolve root-relative URLs to absolute URLs
function resolveRootRelativeUrl($baseUrl, $relativeUrl)
{
    $baseParts = parse_url($baseUrl);
    $basePath = $baseParts['scheme'] . '://' . $baseParts['host'];

    if (isset($baseParts['port'])) {
        $basePath .= ':' . $baseParts['port'];
    }

    $resolvedUrl = rtrim($basePath, '/') . '/' . ltrim($relativeUrl, '/');

    return $resolvedUrl;
}

// Call the function from the first script to get the base URL
function getBaseURL() {
    $protocol = isset($_SERVER['HTTPS']) && $_SERVER['HTTPS'] === 'on' ? 'https' : 'http';
    $host = $_SERVER['HTTP_HOST'];
    $baseURL = $protocol . '://' . $host;
    return $baseURL;
}

$baseURL = getBaseURL();

// URL to crawl (root-relative or absolute)
$url = $baseURL; // Replace with the desired URL

// Call the crawlWebsite function
$pages = crawlWebsite($url);

// Display the list of webpages
echo "<h2>List of Webpages:</h2>";
echo "<ul>";
foreach ($pages as $page) {
    echo "<li>$page</li>";
}
echo "</ul>";
?>

</body>
</html>
